@@ -37,7 +37,7 @@ class SDK:
 
     def get_tasks(self, project_id, page=1, limit=10, status=None):
         url = "%s/v2/project/%s/tasks?page=%s&limit=%s" % (self.host, project_id, page, limit)
-        if status :
+        if status:
             url += "&status[eq]=%s" % status
         payload = {}
         headers = {
@@ -58,6 +58,25 @@ class SDK:
         response = requests.request("GET", url, headers=headers, data=payload)
         return response.json()
 
+    def assign_task(self, task, userid=None, email=None):
+        url = "%s/v2/task/assign" % self.host
+
+        payload = {"task": task}
+        if userid:
+            payload["user"] = userid
+        if email:
+            payload["username"] = email
+        else:
+            return Exception("userid or email required!")
+
+        payload = json.dumps(payload)
+        headers = {
+            'Content-Type': 'application/json',
+            'apikey': self.api_key
+        }
+        response = requests.request("POST", url, headers=headers, data=payload)
+        return response.json()
+
     def upload_files(self, project_id, file_paths):
         url = "%s/v2/project/%s/upload" % (self.host, project_id)
 
